#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/


        #include <session.h>
        #include <tf_model.h>
        #include <ops/tf.h>
        #include <ops/noop.h>
        #include <ops/blas.h>
        #include <ops/minmax.h>
        #include <ops/genop.h>
        #include <ops/image.h>
        #include <resources/tf_saved_model.h>
        #include <resources/shared_object.h>
        #include <plugin.h>
        #include <ops/fpga.h>
        #include <ops/exec.h>
        

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_op *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 175), // struct vaccel_op *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_op *, size_t)
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_plugin *)
/*  8 */ _CFFI_OP(_CFFI_OP_POINTER, 176), // struct vaccel_plugin *
/*  9 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *)
/* 11 */ _CFFI_OP(_CFFI_OP_POINTER, 178), // struct vaccel_session *
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 13 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, char const *, char const *, struct vaccel_arg *, size_t, struct vaccel_arg *, size_t)
/* 14 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 15 */ _CFFI_OP(_CFFI_OP_POINTER, 168), // char const *
/* 16 */ _CFFI_OP(_CFFI_OP_NOOP, 15),
/* 17 */ _CFFI_OP(_CFFI_OP_POINTER, 173), // struct vaccel_arg *
/* 18 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 19 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 20 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, double const *, int, int, int, double *, double *, double *)
/* 23 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 24 */ _CFFI_OP(_CFFI_OP_POINTER, 169), // double const *
/* 25 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 26 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 27 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 28 */ _CFFI_OP(_CFFI_OP_POINTER, 169), // double *
/* 29 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 30 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 31 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, float *, float *, float *, float *, size_t)
/* 33 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 34 */ _CFFI_OP(_CFFI_OP_POINTER, 59), // float *
/* 35 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 36 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 37 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 38 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 40 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, float *, float *, float *, size_t, size_t)
/* 41 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 42 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 43 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 44 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 45 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 46 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, int *, int *, size_t)
/* 49 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 50 */ _CFFI_OP(_CFFI_OP_POINTER, 25), // int *
/* 51 */ _CFFI_OP(_CFFI_OP_NOOP, 50),
/* 52 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, int64_t, int64_t, int64_t, float, float *, int64_t, float *, int64_t, float, float *, int64_t)
/* 55 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 56 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23), // int64_t
/* 57 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 58 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 59 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 13), // float
/* 60 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 61 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 63 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 64 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 13),
/* 65 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 66 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 67 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, struct vaccel_arg *, int, struct vaccel_arg *, int)
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 70 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 71 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 72 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 73 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 74 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, struct vaccel_resource *)
/* 76 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 77 */ _CFFI_OP(_CFFI_OP_POINTER, 177), // struct vaccel_resource *
/* 78 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 79 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, struct vaccel_shared_object *, char const *, struct vaccel_arg *, size_t, struct vaccel_arg *, size_t)
/* 80 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 81 */ _CFFI_OP(_CFFI_OP_POINTER, 179), // struct vaccel_shared_object *
/* 82 */ _CFFI_OP(_CFFI_OP_NOOP, 15),
/* 83 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 84 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 85 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 86 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, struct vaccel_tf_saved_model *, struct vaccel_tf_status *)
/* 89 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 90 */ _CFFI_OP(_CFFI_OP_POINTER, 183), // struct vaccel_tf_saved_model *
/* 91 */ _CFFI_OP(_CFFI_OP_POINTER, 184), // struct vaccel_tf_status *
/* 92 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, struct vaccel_tf_saved_model const *, struct vaccel_tf_buffer const *, struct vaccel_tf_node const *, struct vaccel_tf_tensor * const *, int, struct vaccel_tf_node const *, struct vaccel_tf_tensor * *, int, struct vaccel_tf_status *)
/* 94 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 95 */ _CFFI_OP(_CFFI_OP_POINTER, 183), // struct vaccel_tf_saved_model const *
/* 96 */ _CFFI_OP(_CFFI_OP_POINTER, 180), // struct vaccel_tf_buffer const *
/* 97 */ _CFFI_OP(_CFFI_OP_POINTER, 182), // struct vaccel_tf_node const *
/* 98 */ _CFFI_OP(_CFFI_OP_POINTER, 185), // struct vaccel_tf_tensor * const *
/* 99 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 100 */ _CFFI_OP(_CFFI_OP_NOOP, 97),
/* 101 */ _CFFI_OP(_CFFI_OP_POINTER, 185), // struct vaccel_tf_tensor * *
/* 102 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 103 */ _CFFI_OP(_CFFI_OP_NOOP, 91),
/* 104 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, uint32_t)
/* 106 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 107 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22), // uint32_t
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, void const *, unsigned char *, size_t, size_t)
/* 110 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 111 */ _CFFI_OP(_CFFI_OP_POINTER, 192), // void const *
/* 112 */ _CFFI_OP(_CFFI_OP_POINTER, 189), // unsigned char *
/* 113 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 114 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 116 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_session *, void const *, unsigned char *, unsigned char *, size_t, size_t, size_t)
/* 117 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 118 */ _CFFI_OP(_CFFI_OP_NOOP, 111),
/* 119 */ _CFFI_OP(_CFFI_OP_NOOP, 112),
/* 120 */ _CFFI_OP(_CFFI_OP_NOOP, 112),
/* 121 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 122 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 123 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 124 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_shared_object *)
/* 126 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 127 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 128 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_shared_object *, char const *)
/* 129 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 130 */ _CFFI_OP(_CFFI_OP_NOOP, 15),
/* 131 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_shared_object *, uint8_t const *, size_t)
/* 133 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 134 */ _CFFI_OP(_CFFI_OP_POINTER, 188), // uint8_t const *
/* 135 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 136 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 137 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_tf_model *)
/* 138 */ _CFFI_OP(_CFFI_OP_POINTER, 181), // struct vaccel_tf_model *
/* 139 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 140 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_tf_model *, char const *)
/* 141 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 142 */ _CFFI_OP(_CFFI_OP_NOOP, 15),
/* 143 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 144 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_tf_model *, uint8_t const *, size_t)
/* 145 */ _CFFI_OP(_CFFI_OP_NOOP, 138),
/* 146 */ _CFFI_OP(_CFFI_OP_NOOP, 134),
/* 147 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 148 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 149 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_tf_saved_model *)
/* 150 */ _CFFI_OP(_CFFI_OP_NOOP, 90),
/* 151 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 152 */ _CFFI_OP(_CFFI_OP_FUNCTION, 25), // int()(struct vaccel_tf_saved_model *, char const *)
/* 153 */ _CFFI_OP(_CFFI_OP_NOOP, 90),
/* 154 */ _CFFI_OP(_CFFI_OP_NOOP, 15),
/* 155 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 156 */ _CFFI_OP(_CFFI_OP_FUNCTION, 134), // uint8_t const *()(struct vaccel_shared_object *, size_t *)
/* 157 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 158 */ _CFFI_OP(_CFFI_OP_POINTER, 5), // size_t *
/* 159 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 160 */ _CFFI_OP(_CFFI_OP_FUNCTION, 190), // vaccel_id_t()(struct vaccel_shared_object const *)
/* 161 */ _CFFI_OP(_CFFI_OP_POINTER, 179), // struct vaccel_shared_object const *
/* 162 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 163 */ _CFFI_OP(_CFFI_OP_FUNCTION, 190), // vaccel_id_t()(struct vaccel_tf_model const *)
/* 164 */ _CFFI_OP(_CFFI_OP_POINTER, 181), // struct vaccel_tf_model const *
/* 165 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 166 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1), // _Bool
/* 167 */ _CFFI_OP(_CFFI_OP_POINTER, 168), // char *
/* 168 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 169 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/* 170 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // enum vaccel_tf_data_type
/* 171 */ _CFFI_OP(_CFFI_OP_POINTER, 172), // int32_t *
/* 172 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 21), // int32_t
/* 173 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // struct vaccel_arg
/* 174 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // struct vaccel_file
/* 175 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // struct vaccel_op
/* 176 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // struct vaccel_plugin
/* 177 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // struct vaccel_resource
/* 178 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // struct vaccel_session
/* 179 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // struct vaccel_shared_object
/* 180 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // struct vaccel_tf_buffer
/* 181 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // struct vaccel_tf_model
/* 182 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // struct vaccel_tf_node
/* 183 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // struct vaccel_tf_saved_model
/* 184 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // struct vaccel_tf_status
/* 185 */ _CFFI_OP(_CFFI_OP_POINTER, 186), // struct vaccel_tf_tensor *
/* 186 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // struct vaccel_tf_tensor
/* 187 */ _CFFI_OP(_CFFI_OP_POINTER, 188), // uint8_t *
/* 188 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 18), // uint8_t
/* 189 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 190 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, _cffi_prim_int(sizeof(vaccel_id_t), (
           ((vaccel_id_t)-1) | 0 /* check that vaccel_id_t is an integer type */
         ) <= 0)), // vaccel_id_t
/* 191 */ _CFFI_OP(_CFFI_OP_POINTER, 192), // void *
/* 192 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_VACCEL_TF_FLOAT(unsigned long long *o)
{
  int n = (VACCEL_TF_FLOAT) <= 0;
  *o = (unsigned long long)((VACCEL_TF_FLOAT) | 0);  /* check that VACCEL_TF_FLOAT is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_DOUBLE(unsigned long long *o)
{
  int n = (VACCEL_TF_DOUBLE) <= 0;
  *o = (unsigned long long)((VACCEL_TF_DOUBLE) | 0);  /* check that VACCEL_TF_DOUBLE is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_INT32(unsigned long long *o)
{
  int n = (VACCEL_TF_INT32) <= 0;
  *o = (unsigned long long)((VACCEL_TF_INT32) | 0);  /* check that VACCEL_TF_INT32 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_UINT8(unsigned long long *o)
{
  int n = (VACCEL_TF_UINT8) <= 0;
  *o = (unsigned long long)((VACCEL_TF_UINT8) | 0);  /* check that VACCEL_TF_UINT8 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_INT16(unsigned long long *o)
{
  int n = (VACCEL_TF_INT16) <= 0;
  *o = (unsigned long long)((VACCEL_TF_INT16) | 0);  /* check that VACCEL_TF_INT16 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_INT8(unsigned long long *o)
{
  int n = (VACCEL_TF_INT8) <= 0;
  *o = (unsigned long long)((VACCEL_TF_INT8) | 0);  /* check that VACCEL_TF_INT8 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_STRING(unsigned long long *o)
{
  int n = (VACCEL_TF_STRING) <= 0;
  *o = (unsigned long long)((VACCEL_TF_STRING) | 0);  /* check that VACCEL_TF_STRING is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_COMPLEX64(unsigned long long *o)
{
  int n = (VACCEL_TF_COMPLEX64) <= 0;
  *o = (unsigned long long)((VACCEL_TF_COMPLEX64) | 0);  /* check that VACCEL_TF_COMPLEX64 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_COMPLEX(unsigned long long *o)
{
  int n = (VACCEL_TF_COMPLEX) <= 0;
  *o = (unsigned long long)((VACCEL_TF_COMPLEX) | 0);  /* check that VACCEL_TF_COMPLEX is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_INT64(unsigned long long *o)
{
  int n = (VACCEL_TF_INT64) <= 0;
  *o = (unsigned long long)((VACCEL_TF_INT64) | 0);  /* check that VACCEL_TF_INT64 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_BOOL(unsigned long long *o)
{
  int n = (VACCEL_TF_BOOL) <= 0;
  *o = (unsigned long long)((VACCEL_TF_BOOL) | 0);  /* check that VACCEL_TF_BOOL is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_QINT8(unsigned long long *o)
{
  int n = (VACCEL_TF_QINT8) <= 0;
  *o = (unsigned long long)((VACCEL_TF_QINT8) | 0);  /* check that VACCEL_TF_QINT8 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_QUINT8(unsigned long long *o)
{
  int n = (VACCEL_TF_QUINT8) <= 0;
  *o = (unsigned long long)((VACCEL_TF_QUINT8) | 0);  /* check that VACCEL_TF_QUINT8 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_QINT32(unsigned long long *o)
{
  int n = (VACCEL_TF_QINT32) <= 0;
  *o = (unsigned long long)((VACCEL_TF_QINT32) | 0);  /* check that VACCEL_TF_QINT32 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_BFLOAT16(unsigned long long *o)
{
  int n = (VACCEL_TF_BFLOAT16) <= 0;
  *o = (unsigned long long)((VACCEL_TF_BFLOAT16) | 0);  /* check that VACCEL_TF_BFLOAT16 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_QINT16(unsigned long long *o)
{
  int n = (VACCEL_TF_QINT16) <= 0;
  *o = (unsigned long long)((VACCEL_TF_QINT16) | 0);  /* check that VACCEL_TF_QINT16 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_QUINT16(unsigned long long *o)
{
  int n = (VACCEL_TF_QUINT16) <= 0;
  *o = (unsigned long long)((VACCEL_TF_QUINT16) | 0);  /* check that VACCEL_TF_QUINT16 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_UINT16(unsigned long long *o)
{
  int n = (VACCEL_TF_UINT16) <= 0;
  *o = (unsigned long long)((VACCEL_TF_UINT16) | 0);  /* check that VACCEL_TF_UINT16 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_COMPLEX128(unsigned long long *o)
{
  int n = (VACCEL_TF_COMPLEX128) <= 0;
  *o = (unsigned long long)((VACCEL_TF_COMPLEX128) | 0);  /* check that VACCEL_TF_COMPLEX128 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_HALF(unsigned long long *o)
{
  int n = (VACCEL_TF_HALF) <= 0;
  *o = (unsigned long long)((VACCEL_TF_HALF) | 0);  /* check that VACCEL_TF_HALF is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_RESOURCE(unsigned long long *o)
{
  int n = (VACCEL_TF_RESOURCE) <= 0;
  *o = (unsigned long long)((VACCEL_TF_RESOURCE) | 0);  /* check that VACCEL_TF_RESOURCE is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_VARIANT(unsigned long long *o)
{
  int n = (VACCEL_TF_VARIANT) <= 0;
  *o = (unsigned long long)((VACCEL_TF_VARIANT) | 0);  /* check that VACCEL_TF_VARIANT is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_UINT32(unsigned long long *o)
{
  int n = (VACCEL_TF_UINT32) <= 0;
  *o = (unsigned long long)((VACCEL_TF_UINT32) | 0);  /* check that VACCEL_TF_UINT32 is an integer */
  return n;
}

static int _cffi_const_VACCEL_TF_UINT64(unsigned long long *o)
{
  int n = (VACCEL_TF_UINT64) <= 0;
  *o = (unsigned long long)((VACCEL_TF_UINT64) | 0);  /* check that VACCEL_TF_UINT64 is an integer */
  return n;
}

static int _cffi_d_register_plugin(struct vaccel_plugin * x0)
{
  return register_plugin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_register_plugin(PyObject *self, PyObject *arg0)
{
  struct vaccel_plugin * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(8), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_plugin *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(8), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = register_plugin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_register_plugin _cffi_d_register_plugin
#endif

static int _cffi_d_register_plugin_function(struct vaccel_op * x0)
{
  return register_plugin_function(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_register_plugin_function(PyObject *self, PyObject *arg0)
{
  struct vaccel_op * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_op *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = register_plugin_function(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_register_plugin_function _cffi_d_register_plugin_function
#endif

static int _cffi_d_register_plugin_functions(struct vaccel_op * x0, size_t x1)
{
  return register_plugin_functions(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_register_plugin_functions(PyObject *self, PyObject *args)
{
  struct vaccel_op * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "register_plugin_functions", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_op *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = register_plugin_functions(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_register_plugin_functions _cffi_d_register_plugin_functions
#endif

static int _cffi_d_unregister_plugin(struct vaccel_plugin * x0)
{
  return unregister_plugin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_unregister_plugin(PyObject *self, PyObject *arg0)
{
  struct vaccel_plugin * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(8), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_plugin *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(8), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = unregister_plugin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_unregister_plugin _cffi_d_unregister_plugin
#endif

static int _cffi_d_vaccel_exec(struct vaccel_session * x0, char const * x1, char const * x2, struct vaccel_arg * x3, size_t x4, struct vaccel_arg * x5, size_t x6)
{
  return vaccel_exec(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_exec(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  char const * x1;
  char const * x2;
  struct vaccel_arg * x3;
  size_t x4;
  struct vaccel_arg * x5;
  size_t x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "vaccel_exec", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(15), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(15), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(15), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(15), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (struct vaccel_arg *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (struct vaccel_arg *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = _cffi_to_c_int(arg6, size_t);
  if (x6 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_exec(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_exec _cffi_d_vaccel_exec
#endif

static int _cffi_d_vaccel_exec_with_resource(struct vaccel_session * x0, struct vaccel_shared_object * x1, char const * x2, struct vaccel_arg * x3, size_t x4, struct vaccel_arg * x5, size_t x6)
{
  return vaccel_exec_with_resource(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_exec_with_resource(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_shared_object * x1;
  char const * x2;
  struct vaccel_arg * x3;
  size_t x4;
  struct vaccel_arg * x5;
  size_t x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "vaccel_exec_with_resource", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_shared_object *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(81), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(15), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(15), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (struct vaccel_arg *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (struct vaccel_arg *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = _cffi_to_c_int(arg6, size_t);
  if (x6 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_exec_with_resource(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_exec_with_resource _cffi_d_vaccel_exec_with_resource
#endif

static int _cffi_d_vaccel_fpga_arraycopy(struct vaccel_session * x0, int * x1, int * x2, size_t x3)
{
  return vaccel_fpga_arraycopy(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_fpga_arraycopy(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  int * x1;
  int * x2;
  size_t x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "vaccel_fpga_arraycopy", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(50), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(50), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(50), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(50), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_fpga_arraycopy(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_fpga_arraycopy _cffi_d_vaccel_fpga_arraycopy
#endif

static int _cffi_d_vaccel_fpga_parallel(struct vaccel_session * x0, float * x1, float * x2, float * x3, float * x4, size_t x5)
{
  return vaccel_fpga_parallel(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_fpga_parallel(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  float * x1;
  float * x2;
  float * x3;
  float * x4;
  size_t x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "vaccel_fpga_parallel", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = _cffi_to_c_int(arg5, size_t);
  if (x5 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_fpga_parallel(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_fpga_parallel _cffi_d_vaccel_fpga_parallel
#endif

static int _cffi_d_vaccel_fpga_vadd(struct vaccel_session * x0, float * x1, float * x2, float * x3, size_t x4, size_t x5)
{
  return vaccel_fpga_vadd(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_fpga_vadd(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  float * x1;
  float * x2;
  float * x3;
  size_t x4;
  size_t x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "vaccel_fpga_vadd", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, size_t);
  if (x5 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_fpga_vadd(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_fpga_vadd _cffi_d_vaccel_fpga_vadd
#endif

static int _cffi_d_vaccel_genop(struct vaccel_session * x0, struct vaccel_arg * x1, int x2, struct vaccel_arg * x3, int x4)
{
  return vaccel_genop(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_genop(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_arg * x1;
  int x2;
  struct vaccel_arg * x3;
  int x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "vaccel_genop", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_arg *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (struct vaccel_arg *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_genop(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_genop _cffi_d_vaccel_genop
#endif

static int _cffi_d_vaccel_image_classification(struct vaccel_session * x0, void const * x1, unsigned char * x2, unsigned char * x3, size_t x4, size_t x5, size_t x6)
{
  return vaccel_image_classification(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_image_classification(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  void const * x1;
  unsigned char * x2;
  unsigned char * x3;
  size_t x4;
  size_t x5;
  size_t x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "vaccel_image_classification", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(111), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(112), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(112), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(112), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(112), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, size_t);
  if (x5 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, size_t);
  if (x6 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_image_classification(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_image_classification _cffi_d_vaccel_image_classification
#endif

static int _cffi_d_vaccel_image_depth(struct vaccel_session * x0, void const * x1, unsigned char * x2, size_t x3, size_t x4)
{
  return vaccel_image_depth(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_image_depth(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  void const * x1;
  unsigned char * x2;
  size_t x3;
  size_t x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "vaccel_image_depth", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(111), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(112), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(112), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_image_depth(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_image_depth _cffi_d_vaccel_image_depth
#endif

static int _cffi_d_vaccel_image_detection(struct vaccel_session * x0, void const * x1, unsigned char * x2, size_t x3, size_t x4)
{
  return vaccel_image_detection(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_image_detection(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  void const * x1;
  unsigned char * x2;
  size_t x3;
  size_t x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "vaccel_image_detection", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(111), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(112), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(112), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_image_detection(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_image_detection _cffi_d_vaccel_image_detection
#endif

static int _cffi_d_vaccel_image_pose(struct vaccel_session * x0, void const * x1, unsigned char * x2, size_t x3, size_t x4)
{
  return vaccel_image_pose(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_image_pose(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  void const * x1;
  unsigned char * x2;
  size_t x3;
  size_t x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "vaccel_image_pose", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(111), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(112), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(112), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_image_pose(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_image_pose _cffi_d_vaccel_image_pose
#endif

static int _cffi_d_vaccel_image_segmentation(struct vaccel_session * x0, void const * x1, unsigned char * x2, size_t x3, size_t x4)
{
  return vaccel_image_segmentation(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_image_segmentation(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  void const * x1;
  unsigned char * x2;
  size_t x3;
  size_t x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "vaccel_image_segmentation", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(111), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(112), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(112), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, size_t);
  if (x4 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_image_segmentation(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_image_segmentation _cffi_d_vaccel_image_segmentation
#endif

static int _cffi_d_vaccel_minmax(struct vaccel_session * x0, double const * x1, int x2, int x3, int x4, double * x5, double * x6, double * x7)
{
  return vaccel_minmax(x0, x1, x2, x3, x4, x5, x6, x7);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_minmax(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  double const * x1;
  int x2;
  int x3;
  int x4;
  double * x5;
  double * x6;
  double * x7;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;

  if (!PyArg_UnpackTuple(args, "vaccel_minmax", 8, 8, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(24), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(24), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg6, (char **)&x6);
  if (datasize != 0) {
    x6 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg6, (char **)&x6,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg7, (char **)&x7);
  if (datasize != 0) {
    x7 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg7, (char **)&x7,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_minmax(x0, x1, x2, x3, x4, x5, x6, x7); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_minmax _cffi_d_vaccel_minmax
#endif

static int _cffi_d_vaccel_noop(struct vaccel_session * x0)
{
  return vaccel_noop(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_noop(PyObject *self, PyObject *arg0)
{
  struct vaccel_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_noop(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_noop _cffi_d_vaccel_noop
#endif

static int _cffi_d_vaccel_sess_free(struct vaccel_session * x0)
{
  return vaccel_sess_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_sess_free(PyObject *self, PyObject *arg0)
{
  struct vaccel_session * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_sess_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_sess_free _cffi_d_vaccel_sess_free
#endif

static int _cffi_d_vaccel_sess_has_resource(struct vaccel_session * x0, struct vaccel_resource * x1)
{
  return vaccel_sess_has_resource(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_sess_has_resource(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_resource * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_sess_has_resource", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(77), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_resource *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(77), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_sess_has_resource(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_sess_has_resource _cffi_d_vaccel_sess_has_resource
#endif

static int _cffi_d_vaccel_sess_init(struct vaccel_session * x0, uint32_t x1)
{
  return vaccel_sess_init(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_sess_init(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_sess_init", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_sess_init(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_sess_init _cffi_d_vaccel_sess_init
#endif

static int _cffi_d_vaccel_sess_register(struct vaccel_session * x0, struct vaccel_resource * x1)
{
  return vaccel_sess_register(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_sess_register(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_resource * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_sess_register", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(77), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_resource *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(77), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_sess_register(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_sess_register _cffi_d_vaccel_sess_register
#endif

static int _cffi_d_vaccel_sess_unregister(struct vaccel_session * x0, struct vaccel_resource * x1)
{
  return vaccel_sess_unregister(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_sess_unregister(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_resource * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_sess_unregister", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(77), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_resource *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(77), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_sess_unregister(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_sess_unregister _cffi_d_vaccel_sess_unregister
#endif

static int _cffi_d_vaccel_sgemm(struct vaccel_session * x0, int64_t x1, int64_t x2, int64_t x3, float x4, float * x5, int64_t x6, float * x7, int64_t x8, float x9, float * x10, int64_t x11)
{
  return vaccel_sgemm(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_sgemm(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  int64_t x1;
  int64_t x2;
  int64_t x3;
  float x4;
  float * x5;
  int64_t x6;
  float * x7;
  int64_t x8;
  float x9;
  float * x10;
  int64_t x11;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;
  PyObject *arg8;
  PyObject *arg9;
  PyObject *arg10;
  PyObject *arg11;

  if (!PyArg_UnpackTuple(args, "vaccel_sgemm", 12, 12, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7, &arg8, &arg9, &arg10, &arg11))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int64_t);
  if (x1 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, int64_t);
  if (x2 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int64_t);
  if (x3 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = (float)_cffi_to_c_float(arg4);
  if (x4 == (float)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = _cffi_to_c_int(arg6, int64_t);
  if (x6 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg7, (char **)&x7);
  if (datasize != 0) {
    x7 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg7, (char **)&x7,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x8 = _cffi_to_c_int(arg8, int64_t);
  if (x8 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  x9 = (float)_cffi_to_c_float(arg9);
  if (x9 == (float)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg10, (char **)&x10);
  if (datasize != 0) {
    x10 = ((size_t)datasize) <= 640 ? (float *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg10, (char **)&x10,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x11 = _cffi_to_c_int(arg11, int64_t);
  if (x11 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_sgemm(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_sgemm _cffi_d_vaccel_sgemm
#endif

static int _cffi_d_vaccel_shared_object_destroy(struct vaccel_shared_object * x0)
{
  return vaccel_shared_object_destroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_shared_object_destroy(PyObject *self, PyObject *arg0)
{
  struct vaccel_shared_object * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_shared_object *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(81), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_shared_object_destroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_shared_object_destroy _cffi_d_vaccel_shared_object_destroy
#endif

static uint8_t const * _cffi_d_vaccel_shared_object_get(struct vaccel_shared_object * x0, size_t * x1)
{
  return vaccel_shared_object_get(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_shared_object_get(PyObject *self, PyObject *args)
{
  struct vaccel_shared_object * x0;
  size_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint8_t const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_shared_object_get", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_shared_object *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(81), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(158), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (size_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(158), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_shared_object_get(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(134));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_shared_object_get _cffi_d_vaccel_shared_object_get
#endif

static vaccel_id_t _cffi_d_vaccel_shared_object_get_id(struct vaccel_shared_object const * x0)
{
  return vaccel_shared_object_get_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_shared_object_get_id(PyObject *self, PyObject *arg0)
{
  struct vaccel_shared_object const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  vaccel_id_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(161), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_shared_object const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(161), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_shared_object_get_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, vaccel_id_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_shared_object_get_id _cffi_d_vaccel_shared_object_get_id
#endif

static int _cffi_d_vaccel_shared_object_new(struct vaccel_shared_object * x0, char const * x1)
{
  return vaccel_shared_object_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_shared_object_new(PyObject *self, PyObject *args)
{
  struct vaccel_shared_object * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_shared_object_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_shared_object *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(81), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(15), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(15), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_shared_object_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_shared_object_new _cffi_d_vaccel_shared_object_new
#endif

static int _cffi_d_vaccel_shared_object_new_from_buffer(struct vaccel_shared_object * x0, uint8_t const * x1, size_t x2)
{
  return vaccel_shared_object_new_from_buffer(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_shared_object_new_from_buffer(PyObject *self, PyObject *args)
{
  struct vaccel_shared_object * x0;
  uint8_t const * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "vaccel_shared_object_new_from_buffer", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_shared_object *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(81), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(134), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (uint8_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(134), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_shared_object_new_from_buffer(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_shared_object_new_from_buffer _cffi_d_vaccel_shared_object_new_from_buffer
#endif

static int _cffi_d_vaccel_tf_model_destroy(struct vaccel_tf_model * x0)
{
  return vaccel_tf_model_destroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_model_destroy(PyObject *self, PyObject *arg0)
{
  struct vaccel_tf_model * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_model_destroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_model_destroy _cffi_d_vaccel_tf_model_destroy
#endif

static vaccel_id_t _cffi_d_vaccel_tf_model_get_id(struct vaccel_tf_model const * x0)
{
  return vaccel_tf_model_get_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_model_get_id(PyObject *self, PyObject *arg0)
{
  struct vaccel_tf_model const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  vaccel_id_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(164), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_model const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(164), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_model_get_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, vaccel_id_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_model_get_id _cffi_d_vaccel_tf_model_get_id
#endif

static int _cffi_d_vaccel_tf_model_new(struct vaccel_tf_model * x0, char const * x1)
{
  return vaccel_tf_model_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_model_new(PyObject *self, PyObject *args)
{
  struct vaccel_tf_model * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_tf_model_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(15), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(15), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_model_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_model_new _cffi_d_vaccel_tf_model_new
#endif

static int _cffi_d_vaccel_tf_model_new_from_buffer(struct vaccel_tf_model * x0, uint8_t const * x1, size_t x2)
{
  return vaccel_tf_model_new_from_buffer(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_model_new_from_buffer(PyObject *self, PyObject *args)
{
  struct vaccel_tf_model * x0;
  uint8_t const * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "vaccel_tf_model_new_from_buffer", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(134), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (uint8_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(134), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_model_new_from_buffer(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_model_new_from_buffer _cffi_d_vaccel_tf_model_new_from_buffer
#endif

static int _cffi_d_vaccel_tf_saved_model_destroy(struct vaccel_tf_saved_model * x0)
{
  return vaccel_tf_saved_model_destroy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_saved_model_destroy(PyObject *self, PyObject *arg0)
{
  struct vaccel_tf_saved_model * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(90), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_saved_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(90), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_saved_model_destroy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_saved_model_destroy _cffi_d_vaccel_tf_saved_model_destroy
#endif

static int _cffi_d_vaccel_tf_saved_model_register(struct vaccel_tf_saved_model * x0)
{
  return vaccel_tf_saved_model_register(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_saved_model_register(PyObject *self, PyObject *arg0)
{
  struct vaccel_tf_saved_model * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(90), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_saved_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(90), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_saved_model_register(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_saved_model_register _cffi_d_vaccel_tf_saved_model_register
#endif

static int _cffi_d_vaccel_tf_saved_model_set_path(struct vaccel_tf_saved_model * x0, char const * x1)
{
  return vaccel_tf_saved_model_set_path(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_saved_model_set_path(PyObject *self, PyObject *args)
{
  struct vaccel_tf_saved_model * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "vaccel_tf_saved_model_set_path", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(90), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_saved_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(90), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(15), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(15), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_saved_model_set_path(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_saved_model_set_path _cffi_d_vaccel_tf_saved_model_set_path
#endif

static int _cffi_d_vaccel_tf_session_load(struct vaccel_session * x0, struct vaccel_tf_saved_model * x1, struct vaccel_tf_status * x2)
{
  return vaccel_tf_session_load(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_session_load(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_tf_saved_model * x1;
  struct vaccel_tf_status * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "vaccel_tf_session_load", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(90), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_saved_model *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(90), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(91), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_status *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(91), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_session_load(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_session_load _cffi_d_vaccel_tf_session_load
#endif

static int _cffi_d_vaccel_tf_session_run(struct vaccel_session * x0, struct vaccel_tf_saved_model const * x1, struct vaccel_tf_buffer const * x2, struct vaccel_tf_node const * x3, struct vaccel_tf_tensor * const * x4, int x5, struct vaccel_tf_node const * x6, struct vaccel_tf_tensor * * x7, int x8, struct vaccel_tf_status * x9)
{
  return vaccel_tf_session_run(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_vaccel_tf_session_run(PyObject *self, PyObject *args)
{
  struct vaccel_session * x0;
  struct vaccel_tf_saved_model const * x1;
  struct vaccel_tf_buffer const * x2;
  struct vaccel_tf_node const * x3;
  struct vaccel_tf_tensor * const * x4;
  int x5;
  struct vaccel_tf_node const * x6;
  struct vaccel_tf_tensor * * x7;
  int x8;
  struct vaccel_tf_status * x9;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;
  PyObject *arg8;
  PyObject *arg9;

  if (!PyArg_UnpackTuple(args, "vaccel_tf_session_run", 10, 10, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7, &arg8, &arg9))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct vaccel_session *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(95), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_saved_model const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(95), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(96), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_buffer const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(96), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(97), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(97), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(98), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_tensor * const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(98), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = _cffi_to_c_int(arg5, int);
  if (x5 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(97), arg6, (char **)&x6);
  if (datasize != 0) {
    x6 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(97), arg6, (char **)&x6,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg7, (char **)&x7);
  if (datasize != 0) {
    x7 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_tensor * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg7, (char **)&x7,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x8 = _cffi_to_c_int(arg8, int);
  if (x8 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(91), arg9, (char **)&x9);
  if (datasize != 0) {
    x9 = ((size_t)datasize) <= 640 ? (struct vaccel_tf_status *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(91), arg9, (char **)&x9,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = vaccel_tf_session_run(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_vaccel_tf_session_run _cffi_d_vaccel_tf_session_run
#endif

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_arg(struct vaccel_arg *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->size) | 0);  /* check that 'struct vaccel_arg.size' is an integer */
  { void * *tmp = &p->buf; (void)tmp; }
}
struct _cffi_align_struct_vaccel_arg { char x; struct vaccel_arg y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_file(struct vaccel_file *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->path; (void)tmp; }
  (void)((p->path_owned) | 0);  /* check that 'struct vaccel_file.path_owned' is an integer */
  { uint8_t * *tmp = &p->data; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'struct vaccel_file.size' is an integer */
}
struct _cffi_align_struct_vaccel_file { char x; struct vaccel_file y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_op(struct vaccel_op *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
}
struct _cffi_align_struct_vaccel_op { char x; struct vaccel_op y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_plugin(struct vaccel_plugin *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
}
struct _cffi_align_struct_vaccel_plugin { char x; struct vaccel_plugin y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_session(struct vaccel_session *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->session_id) | 0);  /* check that 'struct vaccel_session.session_id' is an integer */
}
struct _cffi_align_struct_vaccel_session { char x; struct vaccel_session y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_shared_object(struct vaccel_shared_object *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct vaccel_resource * *tmp = &p->resource; (void)tmp; }
  { struct vaccel_file *tmp = &p->file; (void)tmp; }
  { void * *tmp = &p->plugin_data; (void)tmp; }
}
struct _cffi_align_struct_vaccel_shared_object { char x; struct vaccel_shared_object y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_tf_buffer(struct vaccel_tf_buffer *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->data; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'struct vaccel_tf_buffer.size' is an integer */
}
struct _cffi_align_struct_vaccel_tf_buffer { char x; struct vaccel_tf_buffer y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_tf_model(struct vaccel_tf_model *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct vaccel_resource * *tmp = &p->resource; (void)tmp; }
}
struct _cffi_align_struct_vaccel_tf_model { char x; struct vaccel_tf_model y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_tf_node(struct vaccel_tf_node *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  (void)((p->id) | 0);  /* check that 'struct vaccel_tf_node.id' is an integer */
}
struct _cffi_align_struct_vaccel_tf_node { char x; struct vaccel_tf_node y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_tf_saved_model(struct vaccel_tf_saved_model *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct vaccel_resource * *tmp = &p->resource; (void)tmp; }
}
struct _cffi_align_struct_vaccel_tf_saved_model { char x; struct vaccel_tf_saved_model y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_tf_status(struct vaccel_tf_status *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->error_code) | 0);  /* check that 'struct vaccel_tf_status.error_code' is an integer */
  { char const * *tmp = &p->message; (void)tmp; }
}
struct _cffi_align_struct_vaccel_tf_status { char x; struct vaccel_tf_status y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_vaccel_tf_tensor(struct vaccel_tf_tensor *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->data; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'struct vaccel_tf_tensor.size' is an integer */
  (void)((p->nr_dims) | 0);  /* check that 'struct vaccel_tf_tensor.nr_dims' is an integer */
  { int32_t * *tmp = &p->dims; (void)tmp; }
  { enum vaccel_tf_data_type *tmp = &p->data_type; (void)tmp; }
}
struct _cffi_align_struct_vaccel_tf_tensor { char x; struct vaccel_tf_tensor y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "VACCEL_TF_BFLOAT16", (void *)_cffi_const_VACCEL_TF_BFLOAT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_BOOL", (void *)_cffi_const_VACCEL_TF_BOOL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_COMPLEX", (void *)_cffi_const_VACCEL_TF_COMPLEX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_COMPLEX128", (void *)_cffi_const_VACCEL_TF_COMPLEX128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_COMPLEX64", (void *)_cffi_const_VACCEL_TF_COMPLEX64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_DOUBLE", (void *)_cffi_const_VACCEL_TF_DOUBLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_FLOAT", (void *)_cffi_const_VACCEL_TF_FLOAT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_HALF", (void *)_cffi_const_VACCEL_TF_HALF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_INT16", (void *)_cffi_const_VACCEL_TF_INT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_INT32", (void *)_cffi_const_VACCEL_TF_INT32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_INT64", (void *)_cffi_const_VACCEL_TF_INT64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_INT8", (void *)_cffi_const_VACCEL_TF_INT8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_QINT16", (void *)_cffi_const_VACCEL_TF_QINT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_QINT32", (void *)_cffi_const_VACCEL_TF_QINT32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_QINT8", (void *)_cffi_const_VACCEL_TF_QINT8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_QUINT16", (void *)_cffi_const_VACCEL_TF_QUINT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_QUINT8", (void *)_cffi_const_VACCEL_TF_QUINT8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_RESOURCE", (void *)_cffi_const_VACCEL_TF_RESOURCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_STRING", (void *)_cffi_const_VACCEL_TF_STRING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_UINT16", (void *)_cffi_const_VACCEL_TF_UINT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_UINT32", (void *)_cffi_const_VACCEL_TF_UINT32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_UINT64", (void *)_cffi_const_VACCEL_TF_UINT64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_UINT8", (void *)_cffi_const_VACCEL_TF_UINT8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VACCEL_TF_VARIANT", (void *)_cffi_const_VACCEL_TF_VARIANT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "register_plugin", (void *)_cffi_f_register_plugin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 7), (void *)_cffi_d_register_plugin },
  { "register_plugin_function", (void *)_cffi_f_register_plugin_function, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_register_plugin_function },
  { "register_plugin_functions", (void *)_cffi_f_register_plugin_functions, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 3), (void *)_cffi_d_register_plugin_functions },
  { "unregister_plugin", (void *)_cffi_f_unregister_plugin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 7), (void *)_cffi_d_unregister_plugin },
  { "vaccel_exec", (void *)_cffi_f_vaccel_exec, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 13), (void *)_cffi_d_vaccel_exec },
  { "vaccel_exec_with_resource", (void *)_cffi_f_vaccel_exec_with_resource, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 79), (void *)_cffi_d_vaccel_exec_with_resource },
  { "vaccel_fpga_arraycopy", (void *)_cffi_f_vaccel_fpga_arraycopy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 48), (void *)_cffi_d_vaccel_fpga_arraycopy },
  { "vaccel_fpga_parallel", (void *)_cffi_f_vaccel_fpga_parallel, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 32), (void *)_cffi_d_vaccel_fpga_parallel },
  { "vaccel_fpga_vadd", (void *)_cffi_f_vaccel_fpga_vadd, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 40), (void *)_cffi_d_vaccel_fpga_vadd },
  { "vaccel_genop", (void *)_cffi_f_vaccel_genop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 68), (void *)_cffi_d_vaccel_genop },
  { "vaccel_image_classification", (void *)_cffi_f_vaccel_image_classification, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 116), (void *)_cffi_d_vaccel_image_classification },
  { "vaccel_image_depth", (void *)_cffi_f_vaccel_image_depth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 109), (void *)_cffi_d_vaccel_image_depth },
  { "vaccel_image_detection", (void *)_cffi_f_vaccel_image_detection, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 109), (void *)_cffi_d_vaccel_image_detection },
  { "vaccel_image_pose", (void *)_cffi_f_vaccel_image_pose, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 109), (void *)_cffi_d_vaccel_image_pose },
  { "vaccel_image_segmentation", (void *)_cffi_f_vaccel_image_segmentation, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 109), (void *)_cffi_d_vaccel_image_segmentation },
  { "vaccel_minmax", (void *)_cffi_f_vaccel_minmax, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 22), (void *)_cffi_d_vaccel_minmax },
  { "vaccel_noop", (void *)_cffi_f_vaccel_noop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 10), (void *)_cffi_d_vaccel_noop },
  { "vaccel_sess_free", (void *)_cffi_f_vaccel_sess_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 10), (void *)_cffi_d_vaccel_sess_free },
  { "vaccel_sess_has_resource", (void *)_cffi_f_vaccel_sess_has_resource, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 75), (void *)_cffi_d_vaccel_sess_has_resource },
  { "vaccel_sess_init", (void *)_cffi_f_vaccel_sess_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 105), (void *)_cffi_d_vaccel_sess_init },
  { "vaccel_sess_register", (void *)_cffi_f_vaccel_sess_register, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 75), (void *)_cffi_d_vaccel_sess_register },
  { "vaccel_sess_unregister", (void *)_cffi_f_vaccel_sess_unregister, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 75), (void *)_cffi_d_vaccel_sess_unregister },
  { "vaccel_sgemm", (void *)_cffi_f_vaccel_sgemm, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 54), (void *)_cffi_d_vaccel_sgemm },
  { "vaccel_shared_object_destroy", (void *)_cffi_f_vaccel_shared_object_destroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 125), (void *)_cffi_d_vaccel_shared_object_destroy },
  { "vaccel_shared_object_get", (void *)_cffi_f_vaccel_shared_object_get, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 156), (void *)_cffi_d_vaccel_shared_object_get },
  { "vaccel_shared_object_get_id", (void *)_cffi_f_vaccel_shared_object_get_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 160), (void *)_cffi_d_vaccel_shared_object_get_id },
  { "vaccel_shared_object_new", (void *)_cffi_f_vaccel_shared_object_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 128), (void *)_cffi_d_vaccel_shared_object_new },
  { "vaccel_shared_object_new_from_buffer", (void *)_cffi_f_vaccel_shared_object_new_from_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 132), (void *)_cffi_d_vaccel_shared_object_new_from_buffer },
  { "vaccel_tf_model_destroy", (void *)_cffi_f_vaccel_tf_model_destroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 137), (void *)_cffi_d_vaccel_tf_model_destroy },
  { "vaccel_tf_model_get_id", (void *)_cffi_f_vaccel_tf_model_get_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 163), (void *)_cffi_d_vaccel_tf_model_get_id },
  { "vaccel_tf_model_new", (void *)_cffi_f_vaccel_tf_model_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 140), (void *)_cffi_d_vaccel_tf_model_new },
  { "vaccel_tf_model_new_from_buffer", (void *)_cffi_f_vaccel_tf_model_new_from_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 144), (void *)_cffi_d_vaccel_tf_model_new_from_buffer },
  { "vaccel_tf_saved_model_destroy", (void *)_cffi_f_vaccel_tf_saved_model_destroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 149), (void *)_cffi_d_vaccel_tf_saved_model_destroy },
  { "vaccel_tf_saved_model_register", (void *)_cffi_f_vaccel_tf_saved_model_register, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 149), (void *)_cffi_d_vaccel_tf_saved_model_register },
  { "vaccel_tf_saved_model_set_path", (void *)_cffi_f_vaccel_tf_saved_model_set_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_vaccel_tf_saved_model_set_path },
  { "vaccel_tf_session_load", (void *)_cffi_f_vaccel_tf_session_load, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 88), (void *)_cffi_d_vaccel_tf_session_load },
  { "vaccel_tf_session_run", (void *)_cffi_f_vaccel_tf_session_run, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 93), (void *)_cffi_d_vaccel_tf_session_run },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "size", offsetof(struct vaccel_arg, size),
            sizeof(((struct vaccel_arg *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 107) },
  { "buf", offsetof(struct vaccel_arg, buf),
           sizeof(((struct vaccel_arg *)0)->buf),
           _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "path", offsetof(struct vaccel_file, path),
            sizeof(((struct vaccel_file *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 167) },
  { "path_owned", offsetof(struct vaccel_file, path_owned),
                  sizeof(((struct vaccel_file *)0)->path_owned),
                  _CFFI_OP(_CFFI_OP_NOOP, 166) },
  { "data", offsetof(struct vaccel_file, data),
            sizeof(((struct vaccel_file *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 187) },
  { "size", offsetof(struct vaccel_file, size),
            sizeof(((struct vaccel_file *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 5) },
  { "session_id", offsetof(struct vaccel_session, session_id),
                  sizeof(((struct vaccel_session *)0)->session_id),
                  _CFFI_OP(_CFFI_OP_NOOP, 107) },
  { "resource", offsetof(struct vaccel_shared_object, resource),
                sizeof(((struct vaccel_shared_object *)0)->resource),
                _CFFI_OP(_CFFI_OP_NOOP, 77) },
  { "file", offsetof(struct vaccel_shared_object, file),
            sizeof(((struct vaccel_shared_object *)0)->file),
            _CFFI_OP(_CFFI_OP_NOOP, 174) },
  { "plugin_data", offsetof(struct vaccel_shared_object, plugin_data),
                   sizeof(((struct vaccel_shared_object *)0)->plugin_data),
                   _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "data", offsetof(struct vaccel_tf_buffer, data),
            sizeof(((struct vaccel_tf_buffer *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "size", offsetof(struct vaccel_tf_buffer, size),
            sizeof(((struct vaccel_tf_buffer *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 5) },
  { "resource", offsetof(struct vaccel_tf_model, resource),
                sizeof(((struct vaccel_tf_model *)0)->resource),
                _CFFI_OP(_CFFI_OP_NOOP, 77) },
  { "name", offsetof(struct vaccel_tf_node, name),
            sizeof(((struct vaccel_tf_node *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 167) },
  { "id", offsetof(struct vaccel_tf_node, id),
          sizeof(((struct vaccel_tf_node *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 56) },
  { "resource", offsetof(struct vaccel_tf_saved_model, resource),
                sizeof(((struct vaccel_tf_saved_model *)0)->resource),
                _CFFI_OP(_CFFI_OP_NOOP, 77) },
  { "error_code", offsetof(struct vaccel_tf_status, error_code),
                  sizeof(((struct vaccel_tf_status *)0)->error_code),
                  _CFFI_OP(_CFFI_OP_NOOP, 188) },
  { "message", offsetof(struct vaccel_tf_status, message),
               sizeof(((struct vaccel_tf_status *)0)->message),
               _CFFI_OP(_CFFI_OP_NOOP, 15) },
  { "data", offsetof(struct vaccel_tf_tensor, data),
            sizeof(((struct vaccel_tf_tensor *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "size", offsetof(struct vaccel_tf_tensor, size),
            sizeof(((struct vaccel_tf_tensor *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 5) },
  { "nr_dims", offsetof(struct vaccel_tf_tensor, nr_dims),
               sizeof(((struct vaccel_tf_tensor *)0)->nr_dims),
               _CFFI_OP(_CFFI_OP_NOOP, 25) },
  { "dims", offsetof(struct vaccel_tf_tensor, dims),
            sizeof(((struct vaccel_tf_tensor *)0)->dims),
            _CFFI_OP(_CFFI_OP_NOOP, 171) },
  { "data_type", offsetof(struct vaccel_tf_tensor, data_type),
                 sizeof(((struct vaccel_tf_tensor *)0)->data_type),
                 _CFFI_OP(_CFFI_OP_NOOP, 170) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "vaccel_arg", 173, _CFFI_F_CHECK_FIELDS,
    sizeof(struct vaccel_arg), offsetof(struct _cffi_align_struct_vaccel_arg, y), 0, 2 },
  { "vaccel_file", 174, _CFFI_F_CHECK_FIELDS,
    sizeof(struct vaccel_file), offsetof(struct _cffi_align_struct_vaccel_file, y), 2, 4 },
  { "vaccel_op", 175, 0,
    sizeof(struct vaccel_op), offsetof(struct _cffi_align_struct_vaccel_op, y), 6, 0 },
  { "vaccel_plugin", 176, 0,
    sizeof(struct vaccel_plugin), offsetof(struct _cffi_align_struct_vaccel_plugin, y), 6, 0 },
  { "vaccel_resource", 177, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "vaccel_session", 178, 0,
    sizeof(struct vaccel_session), offsetof(struct _cffi_align_struct_vaccel_session, y), 6, 1 },
  { "vaccel_shared_object", 179, _CFFI_F_CHECK_FIELDS,
    sizeof(struct vaccel_shared_object), offsetof(struct _cffi_align_struct_vaccel_shared_object, y), 7, 3 },
  { "vaccel_tf_buffer", 180, _CFFI_F_CHECK_FIELDS,
    sizeof(struct vaccel_tf_buffer), offsetof(struct _cffi_align_struct_vaccel_tf_buffer, y), 10, 2 },
  { "vaccel_tf_model", 181, 0,
    sizeof(struct vaccel_tf_model), offsetof(struct _cffi_align_struct_vaccel_tf_model, y), 12, 1 },
  { "vaccel_tf_node", 182, _CFFI_F_CHECK_FIELDS,
    sizeof(struct vaccel_tf_node), offsetof(struct _cffi_align_struct_vaccel_tf_node, y), 13, 2 },
  { "vaccel_tf_saved_model", 183, 0,
    sizeof(struct vaccel_tf_saved_model), offsetof(struct _cffi_align_struct_vaccel_tf_saved_model, y), 15, 1 },
  { "vaccel_tf_status", 184, _CFFI_F_CHECK_FIELDS,
    sizeof(struct vaccel_tf_status), offsetof(struct _cffi_align_struct_vaccel_tf_status, y), 16, 2 },
  { "vaccel_tf_tensor", 186, 0,
    sizeof(struct vaccel_tf_tensor), offsetof(struct _cffi_align_struct_vaccel_tf_tensor, y), 18, 5 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "vaccel_tf_data_type", 170, _cffi_prim_int(sizeof(enum vaccel_tf_data_type), ((enum vaccel_tf_data_type)-1) <= 0),
    "VACCEL_TF_FLOAT,VACCEL_TF_DOUBLE,VACCEL_TF_INT32,VACCEL_TF_UINT8,VACCEL_TF_INT16,VACCEL_TF_INT8,VACCEL_TF_STRING,VACCEL_TF_COMPLEX64,VACCEL_TF_COMPLEX,VACCEL_TF_INT64,VACCEL_TF_BOOL,VACCEL_TF_QINT8,VACCEL_TF_QUINT8,VACCEL_TF_QINT32,VACCEL_TF_BFLOAT16,VACCEL_TF_QINT16,VACCEL_TF_QUINT16,VACCEL_TF_UINT16,VACCEL_TF_COMPLEX128,VACCEL_TF_HALF,VACCEL_TF_RESOURCE,VACCEL_TF_VARIANT,VACCEL_TF_UINT32,VACCEL_TF_UINT64" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "vaccel_id_t", 190 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  61,  /* num_globals */
  13,  /* num_struct_unions */
  1,  /* num_enums */
  1,  /* num_typenames */
  NULL,  /* no includes */
  193,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__vaccel(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__vaccel(void) { return NULL; }
#  else
     init_vaccel(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__vaccel(void)
{
  return _cffi_init("vaccel._vaccel", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_vaccel(void)
{
  _cffi_init("vaccel._vaccel", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
